@@ -6,7 +6,7 @@ This module build python virtual envrionments
 from pydmt.api.one_source_one_target import OneSourceOneTarget
 from pydmt.utils.subprocess import check_call
 from pydmt.utils.filesystem import mkdir_touch
-from pydmt.utils.python import collect_reqs, get_install_args
+from pydmt.utils.python import collect_reqs, collect_bootstrap_reqs, get_install_args
 
 
 class BuilderReqs(OneSourceOneTarget):
@@ -26,8 +26,12 @@ class BuilderReqs(OneSourceOneTarget):
     python -m pip install [list of packages]
     """
     def build(self) -> None:
-        args = []
-        args.extend(get_install_args())
+        args = get_install_args()
+        packs = collect_bootstrap_reqs()
+        if packs:
+            args.extend(packs)
+            check_call(args)
+        args = get_install_args()
         packs = collect_reqs()
         if packs:
             args.extend(packs)
